@@ -1,67 +1,50 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "grantleethememanager.h"
 #include "grantleetheme_p.h"
 
-#include <KDirWatch>
-#include <KSharedConfig>
-#include <KConfigGroup>
 #include <KActionCollection>
-#include <KToggleAction>
-#include <KLocalizedString>
-#include <KNS3/DownloadDialog>
-#include <KAuthorized>
 #include <KActionMenu>
+#include <KAuthorized>
+#include <KConfigGroup>
+#include <KDirWatch>
+#include <KLocalizedString>
+#include <KNSWidgets/Action>
+#include <KSharedConfig>
+#include <KToggleAction>
 #include <QAction>
 #include <QIcon>
 #include <QPointer>
 
+#include <QActionGroup>
 #include <QDir>
 #include <QDirIterator>
-#include <QActionGroup>
 #include <QStandardPaths>
 
-using namespace GrantleeTheme;
-class Q_DECL_HIDDEN ThemeManager::Private
+namespace GrantleeTheme
+{
+class ThemeManagerPrivate
 {
 public:
-    Private(const QString &type, const QString &desktopFileName, KActionCollection *ac, const QString &relativePath, ThemeManager *qq)
+    ThemeManagerPrivate(const QString &type, const QString &desktopFileName, KActionCollection *ac, const QString &relativePath, ThemeManager *qq)
         : applicationType(type)
         , defaultDesktopFileName(desktopFileName)
-        , actionGroup(nullptr)
-        , menu(nullptr)
         , actionCollection(ac)
         , q(qq)
     {
         watch = new KDirWatch(q);
         initThemesDirectories(relativePath);
         if (KAuthorized::authorize(QStringLiteral("ghns"))) {
-            downloadThemesAction = new QAction(i18n("Download New Themes..."), q);
-            downloadThemesAction->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+            downloadThemesAction = new KNSWidgets::Action(i18n("Download new Templates..."), QString(), q);
             if (actionCollection) {
                 actionCollection->addAction(QStringLiteral("download_header_themes"), downloadThemesAction);
             }
             separatorAction = new QAction(q);
             separatorAction->setSeparator(true);
-            q->connect(downloadThemesAction, &QAction::triggered, q, [this]() {
-                slotDownloadHeaderThemes();
-            });
         }
 
         q->connect(watch, &KDirWatch::dirty, q, [this]() {
@@ -84,21 +67,10 @@ public:
         }
     }
 
-    ~Private()
+    ~ThemeManagerPrivate()
     {
         removeActions();
         themes.clear();
-        if (downloadThemesDialog) {
-            delete downloadThemesDialog.data();
-        }
-    }
-
-    void slotDownloadHeaderThemes()
-    {
-        if (!downloadThemesDialog) {
-            downloadThemesDialog = new KNS3::DownloadDialog(downloadConfigFileName);
-        }
-        downloadThemesDialog.data()->show();
     }
 
     void directoryChanged()
@@ -112,7 +84,7 @@ public:
     {
         if (!init) {
             if (!themesDirectories.isEmpty()) {
-                for (const QString &directory : qAsConst(themesDirectories)) {
+                for (const QString &directory : std::as_const(themesDirectories)) {
                     watch->removeDir(directory);
                 }
             } else {
@@ -123,7 +95,7 @@ public:
         // clear all previous theme information
         themes.clear();
 
-        for (const QString &directory : qAsConst(themesDirectories)) {
+        for (const QString &directory : std::as_const(themesDirectories)) {
             QDirIterator dirIt(directory, QStringList(), QDir::AllDirs | QDir::NoDotAndDotDot);
             QStringList alreadyLoadedThemeName;
             while (dirIt.hasNext()) {
@@ -162,7 +134,7 @@ public:
         if (!actionGroup || !menu) {
             return;
         }
-        for (KToggleAction *action : qAsConst(themesActionList)) {
+        for (KToggleAction *action : std::as_const(themesActionList)) {
             actionGroup->removeAction(action);
             menu->removeAction(action);
             if (actionCollection) {
@@ -195,7 +167,7 @@ public:
         while (i.hasNext()) {
             i.next();
             GrantleeTheme::Theme theme = i.value();
-            KToggleAction *act = new KToggleAction(theme.name(), q);
+            auto act = new KToggleAction(theme.name(), q);
             act->setToolTip(theme.description());
             act->setData(theme.dirName());
             if (theme.dirName() == themeActivated) {
@@ -211,7 +183,7 @@ public:
         }
         if (!themeActivatedFound) {
             if (!themesActionList.isEmpty() && !themeActivated.isEmpty()) {
-                //Activate first item if we removed theme.
+                // Activate first item if we removed theme.
                 KToggleAction *act = themesActionList.at(0);
                 act->setChecked(true);
                 selectTheme(act);
@@ -236,7 +208,7 @@ public:
     void slotThemeSelected()
     {
         if (q->sender()) {
-            KToggleAction *act = qobject_cast<KToggleAction *>(q->sender());
+            auto act = qobject_cast<KToggleAction *>(q->sender());
             selectTheme(act);
             Q_EMIT q->grantleeThemeSelected();
         }
@@ -251,7 +223,7 @@ public:
         if (themeName.isEmpty()) {
             return nullptr;
         }
-        for (KToggleAction *act : qAsConst(themesActionList)) {
+        for (KToggleAction *act : std::as_const(themesActionList)) {
             if (act->data().toString() == themeName) {
                 return static_cast<KToggleAction *>(act);
             }
@@ -270,31 +242,32 @@ public:
 
     QString applicationType;
     QString defaultDesktopFileName;
-    QString downloadConfigFileName;
     QStringList themesDirectories;
     QMap<QString, GrantleeTheme::Theme> themes;
     QVector<KToggleAction *> themesActionList;
     KDirWatch *watch = nullptr;
     QActionGroup *actionGroup = nullptr;
     KActionMenu *menu = nullptr;
-    KActionCollection *actionCollection = nullptr;
+    KActionCollection *const actionCollection;
     QAction *separatorAction = nullptr;
-
-    QAction *downloadThemesAction = nullptr;
-    QPointer<KNS3::DownloadDialog> downloadThemesDialog;
-    ThemeManager *q;
+    KNSWidgets::Action *downloadThemesAction = nullptr;
+    ThemeManager *const q;
 };
+}
 
-ThemeManager::ThemeManager(const QString &applicationType, const QString &defaultDesktopFileName, KActionCollection *actionCollection, const QString &path, QObject *parent)
+using namespace GrantleeTheme;
+
+ThemeManager::ThemeManager(const QString &applicationType,
+                           const QString &defaultDesktopFileName,
+                           KActionCollection *actionCollection,
+                           const QString &path,
+                           QObject *parent)
     : QObject(parent)
-    , d(new Private(applicationType, defaultDesktopFileName, actionCollection, path, this))
+    , d(new ThemeManagerPrivate(applicationType, defaultDesktopFileName, actionCollection, path, this))
 {
 }
 
-ThemeManager::~ThemeManager()
-{
-    delete d;
-}
+ThemeManager::~ThemeManager() = default;
 
 QMap<QString, GrantleeTheme::Theme> ThemeManager::themes() const
 {
@@ -332,7 +305,7 @@ QStringList ThemeManager::displayExtraVariables(const QString &themename) const
             return i.value().displayExtraVariables();
         }
     }
-    return QStringList();
+    return {};
 }
 
 GrantleeTheme::Theme ThemeManager::theme(const QString &themeName)
@@ -342,7 +315,7 @@ GrantleeTheme::Theme ThemeManager::theme(const QString &themeName)
 
 void ThemeManager::setDownloadNewStuffConfigFile(const QString &configFileName)
 {
-    d->downloadConfigFileName = configFileName;
+    d->downloadThemesAction->setConfigFile(configFileName);
 }
 
 QString ThemeManager::pathFromThemes(const QString &themesRelativePath, const QString &themeName, const QString &defaultDesktopFileName)
@@ -351,13 +324,13 @@ QString ThemeManager::pathFromThemes(const QString &themesRelativePath, const QS
     if (!themesRelativePath.isEmpty()) {
         themesDirectories = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, themesRelativePath, QStandardPaths::LocateDirectory);
         if (themesDirectories.count() < 2) {
-            //Make sure to add local directory
+            // Make sure to add local directory
             const QString localDirectory = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + themesRelativePath;
             if (!themesDirectories.contains(localDirectory)) {
                 themesDirectories.append(localDirectory);
             }
         }
-        for (const QString &directory : qAsConst(themesDirectories)) {
+        for (const QString &directory : std::as_const(themesDirectories)) {
             QDirIterator dirIt(directory, QStringList(), QDir::AllDirs | QDir::NoDotAndDotDot);
             while (dirIt.hasNext()) {
                 dirIt.next();
@@ -371,7 +344,7 @@ QString ThemeManager::pathFromThemes(const QString &themesRelativePath, const QS
             }
         }
     }
-    return QString();
+    return {};
 }
 
 GrantleeTheme::Theme ThemeManager::loadTheme(const QString &themePath, const QString &dirName, const QString &defaultDesktopFileName)
